"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const esbuild_1 = require("esbuild");
const esbuildService_1 = require("./esbuildService");
exports.createEsbuildPlugin = async (minify, jsx) => {
    let service;
    const jsxConfig = {
        jsxFactory: jsx.factory,
        jsxFragment: jsx.fragment
    };
    return {
        name: 'vite:esbuild',
        async transform(code, id) {
            const isVueTs = /\.vue\?/.test(id) && id.endsWith('lang=ts');
            if (esbuildService_1.tjsxRE.test(id) || isVueTs) {
                return esbuildService_1.transformWithService(service || (service = await esbuild_1.startService()), code, id, { ...jsxConfig, ...(isVueTs ? { loader: 'ts' } : null) });
            }
        },
        async renderChunk(code, chunk) {
            if (minify) {
                return esbuildService_1.transformWithService(service || (service = await esbuild_1.startService()), code, chunk.fileName, {
                    minify: true
                });
            }
            else {
                return null;
            }
        },
        generateBundle() {
            service && service.stop();
        }
    };
};
