"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const esbuild_1 = require("esbuild");
exports.tjsxRE = /\.(tsx?|jsx)$/;
// Note: when the esbuild service is held in a module level variable, it
// somehow prevents the build process from exiting even after explicitly
// calling service.stop(). Therefore make sure to only use `ensureService`
// in server plugins. Build plugins should contain the service in its creation
// closure and close it in `generateBundle`.
// lazy start the service
let _service;
const ensureService = async () => {
    if (!_service) {
        _service = await esbuild_1.startService();
    }
    return _service;
};
// transform used in server plugins with a more friendly API
exports.transform = async (code, file, options = {}) => {
    return exports.transformWithService(await ensureService(), code, file, options);
};
const sourceMapRE = /\/\/# sourceMappingURL.*/;
// trasnform that takes the service via arguments, used in build plugins
exports.transformWithService = async (service, code, file, options = {}) => {
    try {
        if (!options.loader) {
            options.loader = path_1.default.extname(file).slice(1);
        }
        options.sourcemap = true;
        const result = await service.transform(code, options);
        if (result.warnings.length) {
            console.error(`[vite] warnings while transforming ${file} with esbuild:`);
            // TODO pretty print this
            result.warnings.forEach((w) => console.error(w));
        }
        return {
            code: (result.js || '').replace(sourceMapRE, ''),
            map: result.jsSourceMap
        };
    }
    catch (e) {
        console.error(`[vite] error while transforming ${file} with esbuild:`);
        console.error(e);
        return {
            code: '',
            map: undefined
        };
    }
};
